@@ -6,7 +6,7 @@
 # David Hunter <dhunter@stat.psu.edu> and Mark S. Handcock
 # <handcock@u.washington.edu>.
 #
-# Last Modified 06/05/21
+# Last Modified 06/08/21
 # Licensed under the GNU General Public License version 2 (June, 1991)
 # or greater
 #
@@ -208,7 +208,7 @@ as.matrix.network.adjacency<-function(x,attrname=NULL,expand.bipartite=FALSE,...
   if(is.bipartite(x)&(!expand.bipartite)){
     nactors <- get.network.attribute(x, "bipartite")
     nevents <- network.size(x) - nactors
-    m <- m[0:nactors, nactors+(1:nevents)]
+    m <- m[1:nactors, nactors+(1:nevents), drop=FALSE]
   }
   #Return the result
   m
@@ -260,6 +260,7 @@ as.matrix.network.edgelist<-function(x,attrname=NULL,as.sna.edgelist=FALSE,na.rm
 #
 #' @rdname as.matrix.network
 #' @param store.eid whether the edge ID should be stored in the third column (`.eid`).
+#' @importFrom statnet.common simplify_simple
 #' @export
 as_tibble.network<-function(x,attrnames=(match.arg(unit)=="vertices"),na.rm=TRUE,..., unit=c("edges", "vertices"), store.eid=FALSE){
   unit <- match.arg(unit)
@@ -503,14 +504,18 @@ as.network.matrix<-function(x, matrix.type=NULL,
   if(!is.null(vattr))                        #If given names, use 'em
     unames<-vattr
   #Initialize the network object
-  n<-switch(matrix.type,	#Extract n based on matrix type
-    adjacency=dim(x)[1],
-    incidence=dim(x)[1],
-    bipartite=sum(dim(x)),
-    edgelist=max(x[,1:2]),
-  )
-  if(is.numeric(nattr))                      #If given n, use it
+  if(is.numeric(nattr)){                     #If given n, use it
     n<-nattr
+  }else{  
+    if((matrix.type=="edgelist")&&(NROW(x)==0))
+      stop("Cannot determine network size from zero-length edgelist; assign an n attribute to use data of this type.\n")
+    n<-switch(matrix.type,	#Extract n based on matrix type
+      adjacency=dim(x)[1],
+      incidence=dim(x)[1],
+      bipartite=sum(dim(x)),
+      edgelist=max(x[,1:2]),
+    )
+  }
   if(is.numeric(battr))                      #If given bipartite info, use it
     bipartite<-battr
   
